Jarve

1. Description


Jarve is a module in python created to help developers with A.I


2. Requirements


You need to have python installed.


3. How to install Jarve


To install Jarve, simply open Command Promt(For mac or linux users in might be different) and then type:


pip install jarve


There you go! Know you have Jarve installed on your computer!


4. License


This repository and this module is under the MIT license


For more info:

https://github.com/Kittex0/Jarve